@@ -25,10 +25,10 @@
 
 /**
  * The ivi-layout library supports API set of controlling properties of
- * surface and layer which groups surfaces. An unique ID whose type is integer
- * is required to create surface and layer. With the unique ID, surface and
- * layer are identified to control them. The API set consists of APIs to control
- * properties of surface and layers about followings,
+ * surface and layer which groups surfaces. A unique ID whose type is integer is
+ * required to create surface and layer. With the unique ID, surface and layer
+ * are identified to control them. The API set consists of APIs to control
+ * properties of surface and layers about the following:
  * - visibility.
  * - opacity.
  * - clipping (x,y,width,height).
@@ -45,7 +45,7 @@
  * application surfaces grouped to the layer all together.
  *
  * This API and ABI follow following specifications.
- * http://projects.genivi.org/wayland-ivi-extension/layer-manager-apis
+ * https://at.projects.genivi.org/wiki/display/PROJ/Wayland+IVI+Extension+Design
  */
 
 #ifndef _IVI_LAYOUT_EXPORT_H_
@@ -56,12 +56,15 @@ extern "C" {
 #endif /* __cplusplus */
 
 #include <stdint.h>
+#include <limits.h>
 
 #include "stdbool.h"
-#include "compositor.h"
+#include <libweston/libweston.h>
+#include <libweston/plugin-registry.h>
 
 #define IVI_SUCCEEDED (0)
 #define IVI_FAILED (-1)
+#define IVI_INVALID_ID UINT_MAX
 
 struct ivi_layout_layer;
 struct ivi_layout_screen;
@@ -101,7 +104,7 @@ struct ivi_layout_layer_properties
 	int32_t dest_width;
 	int32_t dest_height;
 	enum wl_output_transform orientation;
-	uint32_t visibility;
+	bool visibility;
 	int32_t transition_type;
 	uint32_t transition_duration;
 	double start_alpha;
@@ -140,6 +143,8 @@ enum ivi_layout_transition_type{
 	IVI_LAYOUT_TRANSITION_MAX,
 };
 
+#define IVI_LAYOUT_API_NAME "ivi_layout_api_v1"
+
 struct ivi_layout_interface {
 
 	/**
@@ -185,6 +190,16 @@ struct ivi_layout_interface {
 	 */
 	int32_t (*add_listener_configure_surface)(struct wl_listener *listener);
 
+	/**
+	 * \brief add a listener for notification when desktop_surface is configured
+	 *
+	 * When an desktop_surface is configured, a signal is emitted
+	 * to the listening controller plugins.
+	 * The pointer of the configured desktop_surface is sent as the void *data argument
+	 * to the wl_listener::notify callback function of the listener.
+	 */
+	int32_t (*add_listener_configure_desktop_surface)(struct wl_listener *listener);
+
 	/**
 	 * \brief Get all ivi_surfaces which are currently registered and managed
 	 * by the services
@@ -275,15 +290,6 @@ struct ivi_layout_interface {
 						     int32_t x, int32_t y,
 						     int32_t width, int32_t height);
 
-	/**
-	 * \brief Sets the orientation of a ivi_surface.
-	 *
-	 * \return IVI_SUCCEEDED if the method call was successful
-	 * \return IVI_FAILED if the method call was failed
-	 */
-	int32_t (*surface_set_orientation)(struct ivi_layout_surface *ivisurf,
-					   enum wl_output_transform orientation);
-
 	/**
 	 * \brief add a listener to listen property changes of ivi_surface
 	 *
@@ -318,6 +324,12 @@ struct ivi_layout_interface {
 					struct ivi_layout_surface *ivisurf,
 					uint32_t duration);
 
+	/**
+	 * \brief set id of ivi_layout_surface
+	 */
+	int32_t (*surface_set_id)(struct ivi_layout_surface *ivisurf,
+				  uint32_t id_surface);
+
 	/**
 	 * layer controller interface
 	 */
@@ -461,15 +473,6 @@ struct ivi_layout_interface {
 						   int32_t x, int32_t y,
 						   int32_t width, int32_t height);
 
-	/**
-	 * \brief Sets the orientation of a ivi_layer.
-	 *
-	 * \return IVI_SUCCEEDED if the method call was successful
-	 * \return IVI_FAILED if the method call was failed
-	 */
-	int32_t (*layer_set_orientation)(struct ivi_layout_layer *ivilayer,
-					 enum wl_output_transform orientation);
-
 	/**
 	 * \brief Add a ivi_surface to a ivi_layer which is currently managed by the service
 	 *
@@ -551,7 +554,7 @@ struct ivi_layout_interface {
 					   const int32_t number);
 
 	/**
-	 * transision animation for layer
+	 * transition animation for layer
 	 */
 	void (*transition_move_layer_cancel)(struct ivi_layout_layer *layer);
 	int32_t (*layer_set_fade_info)(struct ivi_layout_layer* ivilayer,
@@ -578,8 +581,28 @@ struct ivi_layout_interface {
 	 */
 	struct ivi_layout_surface *
 		(*get_surface)(struct weston_surface *surface);
+
+	/**
+	 * \brief Remove a ivi_layer to a weston_output which is currently managed
+	 * by the service
+	 *
+	 * \return IVI_SUCCEEDED if the method call was successful
+	 * \return IVI_FAILED if the method call was failed
+	 */
+	int32_t (*screen_remove_layer)(struct weston_output *output,
+				       struct ivi_layout_layer *removelayer);
 };
 
+static inline const struct ivi_layout_interface *
+ivi_layout_get_api(struct weston_compositor *compositor)
+{
+	const void *api;
+	api = weston_plugin_api_get(compositor, IVI_LAYOUT_API_NAME,
+				    sizeof(struct ivi_layout_interface));
+
+	return (const struct ivi_layout_interface *)api;
+}
+
 #ifdef __cplusplus
 }
 #endif /* __cplusplus */
